==> types_aiobotocore_chime_sdk_media_pipelines-2.5.4-py3-none-any.whl: types_aiobotocore_chime_sdk_media_pipelines/literals.py <==
"""
Type annotations for chime-sdk-media-pipelines service literal definitions.

[Open documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_chime_sdk_media_pipelines/literals/)

Usage::

    ```python
    from types_aiobotocore_chime_sdk_media_pipelines.literals import ActiveSpeakerPositionType

    data: ActiveSpeakerPositionType = "BottomLeft"
    ```
"""
import sys

if sys.version_info >= (3, 9):
    from typing import Literal
else:
    from typing_extensions import Literal


__all__ = (
    "ActiveSpeakerPositionType",
    "ArtifactsConcatenationStateType",
    "ArtifactsStateType",
    "AudioArtifactsConcatenationStateType",
    "AudioChannelsOptionType",
    "AudioMuxTypeType",
    "BorderColorType",
    "CallAnalyticsLanguageCodeType",
    "CanvasOrientationType",
    "ConcatenationSinkTypeType",
    "ConcatenationSourceTypeType",
    "ContentMuxTypeType",
    "ContentRedactionOutputType",
    "ContentShareLayoutOptionType",
    "ContentTypeType",
    "FragmentSelectorTypeType",
    "HighlightColorType",
    "HorizontalTilePositionType",
    "LayoutOptionType",
    "LiveConnectorMuxTypeType",
    "LiveConnectorSinkTypeType",
    "LiveConnectorSourceTypeType",
    "MediaEncodingType",
    "MediaInsightsPipelineConfigurationElementTypeType",
    "MediaPipelineSinkTypeType",
    "MediaPipelineSourceTypeType",
    "MediaPipelineStatusType",
    "MediaPipelineStatusUpdateType",
    "PartialResultsStabilityType",
    "ParticipantRoleType",
    "PresenterPositionType",
    "RealTimeAlertRuleTypeType",
    "RecordingFileFormatType",
    "ResolutionOptionType",
    "SentimentTypeType",
    "TileOrderType",
    "VerticalTilePositionType",
    "VideoMuxTypeType",
    "VocabularyFilterMethodType",
    "VoiceAnalyticsConfigurationStatusType",
    "ChimeSDKMediaPipelinesServiceName",
    "ServiceName",
    "ResourceServiceName",
    "RegionName",
)


ActiveSpeakerPositionType = Literal["BottomLeft", "BottomRight", "TopLeft", "TopRight"]
ArtifactsConcatenationStateType = Literal["Disabled", "Enabled"]
ArtifactsStateType = Literal["Disabled", "Enabled"]
AudioArtifactsConcatenationStateType = Literal["Enabled"]
AudioChannelsOptionType = Literal["Mono", "Stereo"]
AudioMuxTypeType = Literal["AudioOnly", "AudioWithActiveSpeakerVideo", "AudioWithCompositedVideo"]
BorderColorType = Literal["Black", "Blue", "Green", "Red", "White", "Yellow"]
CallAnalyticsLanguageCodeType = Literal[
    "de-DE", "en-AU", "en-GB", "en-US", "es-US", "fr-CA", "fr-FR", "it-IT", "pt-BR"
]
CanvasOrientationType = Literal["Landscape", "Portrait"]
ConcatenationSinkTypeType = Literal["S3Bucket"]
ConcatenationSourceTypeType = Literal["MediaCapturePipeline"]
ContentMuxTypeType = Literal["ContentOnly"]
ContentRedactionOutputType = Literal["redacted", "redacted_and_unredacted"]
ContentShareLayoutOptionType = Literal[
    "ActiveSpeakerOnly", "Horizontal", "PresenterOnly", "Vertical"
]
ContentTypeType = Literal["PII"]
FragmentSelectorTypeType = Literal["ProducerTimestamp", "ServerTimestamp"]
HighlightColorType = Literal["Black", "Blue", "Green", "Red", "White", "Yellow"]
HorizontalTilePositionType = Literal["Bottom", "Top"]
LayoutOptionType = Literal["GridView"]
LiveConnectorMuxTypeType = Literal["AudioWithActiveSpeakerVideo", "AudioWithCompositedVideo"]
LiveConnectorSinkTypeType = Literal["RTMP"]
LiveConnectorSourceTypeType = Literal["ChimeSdkMeeting"]
MediaEncodingType = Literal["pcm"]
MediaInsightsPipelineConfigurationElementTypeType = Literal[
    "AmazonTranscribeCallAnalyticsProcessor",
    "AmazonTranscribeProcessor",
    "KinesisDataStreamSink",
    "LambdaFunctionSink",
    "S3RecordingSink",
    "SnsTopicSink",
    "SqsQueueSink",
    "VoiceAnalyticsProcessor",
]
MediaPipelineSinkTypeType = Literal["S3Bucket"]
MediaPipelineSourceTypeType = Literal["ChimeSdkMeeting"]
MediaPipelineStatusType = Literal[
    "Failed", "InProgress", "Initializing", "Paused", "Stopped", "Stopping"
]
MediaPipelineStatusUpdateType = Literal["Pause", "Resume"]
PartialResultsStabilityType = Literal["high", "low", "medium"]
ParticipantRoleType = Literal["AGENT", "CUSTOMER"]
PresenterPositionType = Literal["BottomLeft", "BottomRight", "TopLeft", "TopRight"]
RealTimeAlertRuleTypeType = Literal["IssueDetection", "KeywordMatch", "Sentiment"]
RecordingFileFormatType = Literal["Opus", "Wav"]
ResolutionOptionType = Literal["FHD", "HD"]
SentimentTypeType = Literal["NEGATIVE"]
TileOrderType = Literal["JoinSequence", "SpeakerSequence"]
VerticalTilePositionType = Literal["Left", "Right"]
VideoMuxTypeType = Literal["VideoOnly"]
VocabularyFilterMethodType = Literal["mask", "remove", "tag"]
VoiceAnalyticsConfigurationStatusType = Literal["Disabled", "Enabled"]
ChimeSDKMediaPipelinesServiceName = Literal["chime-sdk-media-pipelines"]
ServiceName = Literal[
    "accessanalyzer",
    "account",
    "acm",
    "acm-pca",
    "alexaforbusiness",
    "amp",
    "amplify",
    "amplifybackend",
    "amplifyuibuilder",
    "apigateway",
    "apigatewaymanagementapi",
    "apigatewayv2",
    "appconfig",
    "appconfigdata",
    "appfabric",
    "appflow",
    "appintegrations",
    "application-autoscaling",
    "application-insights",
    "applicationcostprofiler",
    "appmesh",
    "apprunner",
    "appstream",
    "appsync",
    "arc-zonal-shift",
    "athena",
    "auditmanager",
    "autoscaling",
    "autoscaling-plans",
    "backup",
    "backup-gateway",
    "backupstorage",
    "batch",
    "billingconductor",
    "braket",
    "budgets",
    "ce",
    "chime",
    "chime-sdk-identity",
    "chime-sdk-media-pipelines",
    "chime-sdk-meetings",
    "chime-sdk-messaging",
    "chime-sdk-voice",
    "cleanrooms",
    "cloud9",
    "cloudcontrol",
    "clouddirectory",
    "cloudformation",
    "cloudfront",
    "cloudhsm",
    "cloudhsmv2",
    "cloudsearch",
    "cloudsearchdomain",
    "cloudtrail",
    "cloudtrail-data",
    "cloudwatch",
    "codeartifact",
    "codebuild",
    "codecatalyst",
    "codecommit",
    "codedeploy",
    "codeguru-reviewer",
    "codeguru-security",
    "codeguruprofiler",
    "codepipeline",
    "codestar",
    "codestar-connections",
    "codestar-notifications",
    "cognito-identity",
    "cognito-idp",
    "cognito-sync",
    "comprehend",
    "comprehendmedical",
    "compute-optimizer",
    "config",
    "connect",
    "connect-contact-lens",
    "connectcampaigns",
    "connectcases",
    "connectparticipant",
    "controltower",
    "cur",
    "customer-profiles",
    "databrew",
    "dataexchange",
    "datapipeline",
    "datasync",
    "dax",
    "detective",
    "devicefarm",
    "devops-guru",
    "directconnect",
    "discovery",
    "dlm",
    "dms",
    "docdb",
    "docdb-elastic",
    "drs",
    "ds",
    "dynamodb",
    "dynamodbstreams",
    "ebs",
    "ec2",
    "ec2-instance-connect",
    "ecr",
    "ecr-public",
    "ecs",
    "efs",
    "eks",
    "elastic-inference",
    "elasticache",
    "elasticbeanstalk",
    "elastictranscoder",
    "elb",
    "elbv2",
    "emr",
    "emr-containers",
    "emr-serverless",
    "entityresolution",
    "es",
    "events",
    "evidently",
    "finspace",
    "finspace-data",
    "firehose",
    "fis",
    "fms",
    "forecast",
    "forecastquery",
    "frauddetector",
    "fsx",
    "gamelift",
    "gamesparks",
    "glacier",
    "globalaccelerator",
    "glue",
    "grafana",
    "greengrass",
    "greengrassv2",
    "groundstation",
    "guardduty",
    "health",
    "healthlake",
    "honeycode",
    "iam",
    "identitystore",
    "imagebuilder",
    "importexport",
    "inspector",
    "inspector2",
    "internetmonitor",
    "iot",
    "iot-data",
    "iot-jobs-data",
    "iot-roborunner",
    "iot1click-devices",
    "iot1click-projects",
    "iotanalytics",
    "iotdeviceadvisor",
    "iotevents",
    "iotevents-data",
    "iotfleethub",
    "iotfleetwise",
    "iotsecuretunneling",
    "iotsitewise",
    "iotthingsgraph",
    "iottwinmaker",
    "iotwireless",
    "ivs",
    "ivs-realtime",
    "ivschat",
    "kafka",
    "kafkaconnect",
    "kendra",
    "kendra-ranking",
    "keyspaces",
    "kinesis",
    "kinesis-video-archived-media",
    "kinesis-video-media",
    "kinesis-video-signaling",
    "kinesis-video-webrtc-storage",
    "kinesisanalytics",
    "kinesisanalyticsv2",
    "kinesisvideo",
    "kms",
    "lakeformation",
    "lambda",
    "lex-models",
    "lex-runtime",
    "lexv2-models",
    "lexv2-runtime",
    "license-manager",
    "license-manager-linux-subscriptions",
    "license-manager-user-subscriptions",
    "lightsail",
    "location",
    "logs",
    "lookoutequipment",
    "lookoutmetrics",
    "lookoutvision",
    "m2",
    "machinelearning",
    "macie",
    "macie2",
    "managedblockchain",
    "managedblockchain-query",
    "marketplace-catalog",
    "marketplace-entitlement",
    "marketplacecommerceanalytics",
    "mediaconnect",
    "mediaconvert",
    "medialive",
    "mediapackage",
    "mediapackage-vod",
    "mediapackagev2",
    "mediastore",
    "mediastore-data",
    "mediatailor",
    "medical-imaging",
    "memorydb",
    "meteringmarketplace",
    "mgh",
    "mgn",
    "migration-hub-refactor-spaces",
    "migrationhub-config",
    "migrationhuborchestrator",
    "migrationhubstrategy",
    "mobile",
    "mq",
    "mturk",
    "mwaa",
    "neptune",
    "network-firewall",
    "networkmanager",
    "nimble",
    "oam",
    "omics",
    "opensearch",
    "opensearchserverless",
    "opsworks",
    "opsworkscm",
    "organizations",
    "osis",
    "outposts",
    "panorama",
    "payment-cryptography",
    "payment-cryptography-data",
    "personalize",
    "personalize-events",
    "personalize-runtime",
    "pi",
    "pinpoint",
    "pinpoint-email",
    "pinpoint-sms-voice",
    "pinpoint-sms-voice-v2",
    "pipes",
    "polly",
    "pricing",
    "privatenetworks",
    "proton",
    "qldb",
    "qldb-session",
    "quicksight",
    "ram",
    "rbin",
    "rds",
    "rds-data",
    "redshift",
    "redshift-data",
    "redshift-serverless",
    "rekognition",
    "resiliencehub",
    "resource-explorer-2",
    "resource-groups",
    "resourcegroupstaggingapi",
    "robomaker",
    "rolesanywhere",
    "route53",
    "route53-recovery-cluster",
    "route53-recovery-control-config",
    "route53-recovery-readiness",
    "route53domains",
    "route53resolver",
    "rum",
    "s3",
    "s3control",
    "s3outposts",
    "sagemaker",
    "sagemaker-a2i-runtime",
    "sagemaker-edge",
    "sagemaker-featurestore-runtime",
    "sagemaker-geospatial",
    "sagemaker-metrics",
    "sagemaker-runtime",
    "savingsplans",
    "scheduler",
    "schemas",
    "sdb",
    "secretsmanager",
    "securityhub",
    "securitylake",
    "serverlessrepo",
    "service-quotas",
    "servicecatalog",
    "servicecatalog-appregistry",
    "servicediscovery",
    "ses",
    "sesv2",
    "shield",
    "signer",
    "simspaceweaver",
    "sms",
    "sms-voice",
    "snow-device-management",
    "snowball",
    "sns",
    "sqs",
    "ssm",
    "ssm-contacts",
    "ssm-incidents",
    "ssm-sap",
    "sso",
    "sso-admin",
    "sso-oidc",
    "stepfunctions",
    "storagegateway",
    "sts",
    "support",
    "support-app",
    "swf",
    "synthetics",
    "textract",
    "timestream-query",
    "timestream-write",
    "tnb",
    "transcribe",
    "transfer",
    "translate",
    "verifiedpermissions",
    "voice-id",
    "vpc-lattice",
    "waf",
    "waf-regional",
    "wafv2",
    "wellarchitected",
    "wisdom",
    "workdocs",
    "worklink",
    "workmail",
    "workmailmessageflow",
    "workspaces",
    "workspaces-web",
    "xray",
]
ResourceServiceName = Literal[
    "cloudformation",
    "cloudwatch",
    "dynamodb",
    "ec2",
    "glacier",
    "iam",
    "opsworks",
    "s3",
    "sns",
    "sqs",
]
RegionName = Literal["ap-southeast-1", "eu-central-1", "us-east-1", "us-west-2"]

==> types_aiobotocore_chime_sdk_media_pipelines-2.8.0-py3-none-any.whl: types_aiobotocore_chime_sdk_media_pipelines/literals.py <==
"""
Type annotations for chime-sdk-media-pipelines service literal definitions.

[Open documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_chime_sdk_media_pipelines/literals/)

Usage::

    ```python
    from types_aiobotocore_chime_sdk_media_pipelines.literals import ActiveSpeakerPositionType

    data: ActiveSpeakerPositionType = "BottomLeft"
    ```
"""

import sys

if sys.version_info >= (3, 12):
    from typing import Literal
else:
    from typing_extensions import Literal


__all__ = (
    "ActiveSpeakerPositionType",
    "ArtifactsConcatenationStateType",
    "ArtifactsStateType",
    "AudioArtifactsConcatenationStateType",
    "AudioChannelsOptionType",
    "AudioMuxTypeType",
    "BorderColorType",
    "CallAnalyticsLanguageCodeType",
    "CanvasOrientationType",
    "ConcatenationSinkTypeType",
    "ConcatenationSourceTypeType",
    "ContentMuxTypeType",
    "ContentRedactionOutputType",
    "ContentShareLayoutOptionType",
    "ContentTypeType",
    "FragmentSelectorTypeType",
    "HighlightColorType",
    "HorizontalTilePositionType",
    "KinesisVideoStreamPoolStatusType",
    "LayoutOptionType",
    "LiveConnectorMuxTypeType",
    "LiveConnectorSinkTypeType",
    "LiveConnectorSourceTypeType",
    "MediaEncodingType",
    "MediaInsightsPipelineConfigurationElementTypeType",
    "MediaPipelineElementStatusType",
    "MediaPipelineSinkTypeType",
    "MediaPipelineSourceTypeType",
    "MediaPipelineStatusType",
    "MediaPipelineStatusUpdateType",
    "MediaPipelineTaskStatusType",
    "MediaStreamPipelineSinkTypeType",
    "MediaStreamTypeType",
    "PartialResultsStabilityType",
    "ParticipantRoleType",
    "PresenterPositionType",
    "RealTimeAlertRuleTypeType",
    "RecordingFileFormatType",
    "ResolutionOptionType",
    "SentimentTypeType",
    "TileOrderType",
    "VerticalTilePositionType",
    "VideoMuxTypeType",
    "VocabularyFilterMethodType",
    "VoiceAnalyticsConfigurationStatusType",
    "VoiceAnalyticsLanguageCodeType",
    "ChimeSDKMediaPipelinesServiceName",
    "ServiceName",
    "ResourceServiceName",
    "RegionName",
)


ActiveSpeakerPositionType = Literal["BottomLeft", "BottomRight", "TopLeft", "TopRight"]
ArtifactsConcatenationStateType = Literal["Disabled", "Enabled"]
ArtifactsStateType = Literal["Disabled", "Enabled"]
AudioArtifactsConcatenationStateType = Literal["Enabled"]
AudioChannelsOptionType = Literal["Mono", "Stereo"]
AudioMuxTypeType = Literal["AudioOnly", "AudioWithActiveSpeakerVideo", "AudioWithCompositedVideo"]
BorderColorType = Literal["Black", "Blue", "Green", "Red", "White", "Yellow"]
CallAnalyticsLanguageCodeType = Literal[
    "de-DE", "en-AU", "en-GB", "en-US", "es-US", "fr-CA", "fr-FR", "it-IT", "pt-BR"
]
CanvasOrientationType = Literal["Landscape", "Portrait"]
ConcatenationSinkTypeType = Literal["S3Bucket"]
ConcatenationSourceTypeType = Literal["MediaCapturePipeline"]
ContentMuxTypeType = Literal["ContentOnly"]
ContentRedactionOutputType = Literal["redacted", "redacted_and_unredacted"]
ContentShareLayoutOptionType = Literal[
    "ActiveSpeakerOnly", "Horizontal", "PresenterOnly", "Vertical"
]
ContentTypeType = Literal["PII"]
FragmentSelectorTypeType = Literal["ProducerTimestamp", "ServerTimestamp"]
HighlightColorType = Literal["Black", "Blue", "Green", "Red", "White", "Yellow"]
HorizontalTilePositionType = Literal["Bottom", "Top"]
KinesisVideoStreamPoolStatusType = Literal["ACTIVE", "CREATING", "DELETING", "FAILED", "UPDATING"]
LayoutOptionType = Literal["GridView"]
LiveConnectorMuxTypeType = Literal["AudioWithActiveSpeakerVideo", "AudioWithCompositedVideo"]
LiveConnectorSinkTypeType = Literal["RTMP"]
LiveConnectorSourceTypeType = Literal["ChimeSdkMeeting"]
MediaEncodingType = Literal["pcm"]
MediaInsightsPipelineConfigurationElementTypeType = Literal[
    "AmazonTranscribeCallAnalyticsProcessor",
    "AmazonTranscribeProcessor",
    "KinesisDataStreamSink",
    "LambdaFunctionSink",
    "S3RecordingSink",
    "SnsTopicSink",
    "SqsQueueSink",
    "VoiceAnalyticsProcessor",
    "VoiceEnhancementSink",
]
MediaPipelineElementStatusType = Literal[
    "Failed",
    "InProgress",
    "Initializing",
    "NotStarted",
    "NotSupported",
    "Paused",
    "Stopped",
    "Stopping",
]
MediaPipelineSinkTypeType = Literal["S3Bucket"]
MediaPipelineSourceTypeType = Literal["ChimeSdkMeeting"]
MediaPipelineStatusType = Literal[
    "Failed", "InProgress", "Initializing", "NotStarted", "Paused", "Stopped", "Stopping"
]
MediaPipelineStatusUpdateType = Literal["Pause", "Resume"]
MediaPipelineTaskStatusType = Literal[
    "Failed", "InProgress", "Initializing", "NotStarted", "Stopped", "Stopping"
]
MediaStreamPipelineSinkTypeType = Literal["KinesisVideoStreamPool"]
MediaStreamTypeType = Literal["IndividualAudio", "MixedAudio"]
PartialResultsStabilityType = Literal["high", "low", "medium"]
ParticipantRoleType = Literal["AGENT", "CUSTOMER"]
PresenterPositionType = Literal["BottomLeft", "BottomRight", "TopLeft", "TopRight"]
RealTimeAlertRuleTypeType = Literal["IssueDetection", "KeywordMatch", "Sentiment"]
RecordingFileFormatType = Literal["Opus", "Wav"]
ResolutionOptionType = Literal["FHD", "HD"]
SentimentTypeType = Literal["NEGATIVE"]
TileOrderType = Literal["JoinSequence", "SpeakerSequence"]
VerticalTilePositionType = Literal["Left", "Right"]
VideoMuxTypeType = Literal["VideoOnly"]
VocabularyFilterMethodType = Literal["mask", "remove", "tag"]
VoiceAnalyticsConfigurationStatusType = Literal["Disabled", "Enabled"]
VoiceAnalyticsLanguageCodeType = Literal["en-US"]
ChimeSDKMediaPipelinesServiceName = Literal["chime-sdk-media-pipelines"]
ServiceName = Literal[
    "accessanalyzer",
    "account",
    "acm",
    "acm-pca",
    "alexaforbusiness",
    "amp",
    "amplify",
    "amplifybackend",
    "amplifyuibuilder",
    "apigateway",
    "apigatewaymanagementapi",
    "apigatewayv2",
    "appconfig",
    "appconfigdata",
    "appfabric",
    "appflow",
    "appintegrations",
    "application-autoscaling",
    "application-insights",
    "applicationcostprofiler",
    "appmesh",
    "apprunner",
    "appstream",
    "appsync",
    "arc-zonal-shift",
    "athena",
    "auditmanager",
    "autoscaling",
    "autoscaling-plans",
    "b2bi",
    "backup",
    "backup-gateway",
    "backupstorage",
    "batch",
    "bcm-data-exports",
    "bedrock",
    "bedrock-runtime",
    "billingconductor",
    "braket",
    "budgets",
    "ce",
    "chime",
    "chime-sdk-identity",
    "chime-sdk-media-pipelines",
    "chime-sdk-meetings",
    "chime-sdk-messaging",
    "chime-sdk-voice",
    "cleanrooms",
    "cloud9",
    "cloudcontrol",
    "clouddirectory",
    "cloudformation",
    "cloudfront",
    "cloudfront-keyvaluestore",
    "cloudhsm",
    "cloudhsmv2",
    "cloudsearch",
    "cloudsearchdomain",
    "cloudtrail",
    "cloudtrail-data",
    "cloudwatch",
    "codeartifact",
    "codebuild",
    "codecatalyst",
    "codecommit",
    "codedeploy",
    "codeguru-reviewer",
    "codeguru-security",
    "codeguruprofiler",
    "codepipeline",
    "codestar",
    "codestar-connections",
    "codestar-notifications",
    "cognito-identity",
    "cognito-idp",
    "cognito-sync",
    "comprehend",
    "comprehendmedical",
    "compute-optimizer",
    "config",
    "connect",
    "connect-contact-lens",
    "connectcampaigns",
    "connectcases",
    "connectparticipant",
    "controltower",
    "cost-optimization-hub",
    "cur",
    "customer-profiles",
    "databrew",
    "dataexchange",
    "datapipeline",
    "datasync",
    "datazone",
    "dax",
    "detective",
    "devicefarm",
    "devops-guru",
    "directconnect",
    "discovery",
    "dlm",
    "dms",
    "docdb",
    "docdb-elastic",
    "drs",
    "ds",
    "dynamodb",
    "dynamodbstreams",
    "ebs",
    "ec2",
    "ec2-instance-connect",
    "ecr",
    "ecr-public",
    "ecs",
    "efs",
    "eks",
    "eks-auth",
    "elastic-inference",
    "elasticache",
    "elasticbeanstalk",
    "elastictranscoder",
    "elb",
    "elbv2",
    "emr",
    "emr-containers",
    "emr-serverless",
    "entityresolution",
    "es",
    "events",
    "evidently",
    "finspace",
    "finspace-data",
    "firehose",
    "fis",
    "fms",
    "forecast",
    "forecastquery",
    "frauddetector",
    "freetier",
    "fsx",
    "gamelift",
    "glacier",
    "globalaccelerator",
    "glue",
    "grafana",
    "greengrass",
    "greengrassv2",
    "groundstation",
    "guardduty",
    "health",
    "healthlake",
    "honeycode",
    "iam",
    "identitystore",
    "imagebuilder",
    "importexport",
    "inspector",
    "inspector-scan",
    "inspector2",
    "internetmonitor",
    "iot",
    "iot-data",
    "iot-jobs-data",
    "iot-roborunner",
    "iot1click-devices",
    "iot1click-projects",
    "iotanalytics",
    "iotdeviceadvisor",
    "iotevents",
    "iotevents-data",
    "iotfleethub",
    "iotfleetwise",
    "iotsecuretunneling",
    "iotsitewise",
    "iotthingsgraph",
    "iottwinmaker",
    "iotwireless",
    "ivs",
    "ivs-realtime",
    "ivschat",
    "kafka",
    "kafkaconnect",
    "kendra",
    "kendra-ranking",
    "keyspaces",
    "kinesis",
    "kinesis-video-archived-media",
    "kinesis-video-media",
    "kinesis-video-signaling",
    "kinesis-video-webrtc-storage",
    "kinesisanalytics",
    "kinesisanalyticsv2",
    "kinesisvideo",
    "kms",
    "lakeformation",
    "lambda",
    "launch-wizard",
    "lex-models",
    "lex-runtime",
    "lexv2-models",
    "lexv2-runtime",
    "license-manager",
    "license-manager-linux-subscriptions",
    "license-manager-user-subscriptions",
    "lightsail",
    "location",
    "logs",
    "lookoutequipment",
    "lookoutmetrics",
    "lookoutvision",
    "m2",
    "machinelearning",
    "macie2",
    "managedblockchain",
    "managedblockchain-query",
    "marketplace-catalog",
    "marketplace-entitlement",
    "marketplacecommerceanalytics",
    "mediaconnect",
    "mediaconvert",
    "medialive",
    "mediapackage",
    "mediapackage-vod",
    "mediapackagev2",
    "mediastore",
    "mediastore-data",
    "mediatailor",
    "medical-imaging",
    "memorydb",
    "meteringmarketplace",
    "mgh",
    "mgn",
    "migration-hub-refactor-spaces",
    "migrationhub-config",
    "migrationhuborchestrator",
    "migrationhubstrategy",
    "mobile",
    "mq",
    "mturk",
    "mwaa",
    "neptune",
    "neptunedata",
    "network-firewall",
    "networkmanager",
    "nimble",
    "oam",
    "omics",
    "opensearch",
    "opensearchserverless",
    "opsworks",
    "opsworkscm",
    "organizations",
    "osis",
    "outposts",
    "panorama",
    "payment-cryptography",
    "payment-cryptography-data",
    "pca-connector-ad",
    "personalize",
    "personalize-events",
    "personalize-runtime",
    "pi",
    "pinpoint",
    "pinpoint-email",
    "pinpoint-sms-voice",
    "pinpoint-sms-voice-v2",
    "pipes",
    "polly",
    "pricing",
    "privatenetworks",
    "proton",
    "qldb",
    "qldb-session",
    "quicksight",
    "ram",
    "rbin",
    "rds",
    "rds-data",
    "redshift",
    "redshift-data",
    "redshift-serverless",
    "rekognition",
    "repostspace",
    "resiliencehub",
    "resource-explorer-2",
    "resource-groups",
    "resourcegroupstaggingapi",
    "robomaker",
    "rolesanywhere",
    "route53",
    "route53-recovery-cluster",
    "route53-recovery-control-config",
    "route53-recovery-readiness",
    "route53domains",
    "route53resolver",
    "rum",
    "s3",
    "s3control",
    "s3outposts",
    "sagemaker",
    "sagemaker-a2i-runtime",
    "sagemaker-edge",
    "sagemaker-featurestore-runtime",
    "sagemaker-geospatial",
    "sagemaker-metrics",
    "sagemaker-runtime",
    "savingsplans",
    "scheduler",
    "schemas",
    "sdb",
    "secretsmanager",
    "securityhub",
    "securitylake",
    "serverlessrepo",
    "service-quotas",
    "servicecatalog",
    "servicecatalog-appregistry",
    "servicediscovery",
    "ses",
    "sesv2",
    "shield",
    "signer",
    "simspaceweaver",
    "sms",
    "sms-voice",
    "snow-device-management",
    "snowball",
    "sns",
    "sqs",
    "ssm",
    "ssm-contacts",
    "ssm-incidents",
    "ssm-sap",
    "sso",
    "sso-admin",
    "sso-oidc",
    "stepfunctions",
    "storagegateway",
    "sts",
    "support",
    "support-app",
    "swf",
    "synthetics",
    "textract",
    "timestream-query",
    "timestream-write",
    "tnb",
    "transcribe",
    "transfer",
    "translate",
    "trustedadvisor",
    "verifiedpermissions",
    "voice-id",
    "vpc-lattice",
    "waf",
    "waf-regional",
    "wafv2",
    "wellarchitected",
    "wisdom",
    "workdocs",
    "worklink",
    "workmail",
    "workmailmessageflow",
    "workspaces",
    "workspaces-thin-client",
    "workspaces-web",
    "xray",
]
ResourceServiceName = Literal[
    "cloudformation",
    "cloudwatch",
    "dynamodb",
    "ec2",
    "glacier",
    "iam",
    "opsworks",
    "s3",
    "sns",
    "sqs",
]
RegionName = Literal["ap-southeast-1", "eu-central-1", "us-east-1", "us-west-2"]
